Skip to contents

Captures supported shinyphaser method calls without evaluating them in R. Browser actions are compiled when passed to an event registration method. Arbitrary R code belongs in the corresponding server_action function.

Usage

browser_actions(...)

Arguments

...

Supported shinyphaser browser action calls.

Value

A browser action specification.