Skip to contents

Launches the sample Shiny application bundled with the package. This is a quick way to see a working shinyphaser game setup.

Usage

run_sample_app()

Value

The value returned by shiny::runApp(). This function is normally called for its side effect of starting the application.