Launches the modular Swamps RPG Shiny application bundled with shinyphaser.
Value
The value returned by shiny::runApp(). This function is normally
called for its side effect of starting the application.
Launches the modular Swamps RPG Shiny application bundled with shinyphaser.
The value returned by shiny::runApp(). This function is normally
called for its side effect of starting the application.