Captures supported shinyphaser method calls without evaluating them in R.
Browser actions are compiled when passed to an event registration method.
Arbitrary R code belongs in the corresponding server_action function.
Captures supported shinyphaser method calls without evaluating them in R.
Browser actions are compiled when passed to an event registration method.
Arbitrary R code belongs in the corresponding server_action function.