Launches the sample Shiny application bundled with the package.
This is a quick way to see a working shinyphaser game setup.
Launches the sample Shiny application bundled with the package.
This is a quick way to see a working shinyphaser game setup.